function [corrCoeff,shift] = corrCoeffShift(x,y)
% CORRSHIFT Normalized Correlation Coefficient with Signal Shift
%   This function calculates the shift between all pairs of signals x and y
%   by using GCC-PHAT. The shifted signals are compared by normalized
%   correlation coefficient.

    maxLength = max([length(x(1,:)),length(y(1,:))]);
    
    numRows = length(x(:,1));
    numCols = length(y(:,1));
    
    x = [x zeros(numRows, maxLength-length(x(1,:)))];
    y = [y zeros(numCols, maxLength-length(x(1,:)))];
    
    corrCoeff = zeros(numRows, numCols);
    shift = zeros(numRows, numCols);

    for row = 1 : numRows
        for col = 1 : numCols
            shift(row, col) = gccphat(x(row,:)', y(col,:)');
            ytemp = delayseq(y(col,:)', shift(row, col))';
            corrCoeff(row, col) = corr(x(row,:)', ytemp');
        end
    end

end
